Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(409)

Unified Diff: gfx/canvas_skia_paint.h

Issue 2862025: Canvas refactoring part 2.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gfx/canvas_skia_mac.mm ('k') | gfx/canvas_skia_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: gfx/canvas_skia_paint.h
===================================================================
--- gfx/canvas_skia_paint.h (revision 50452)
+++ gfx/canvas_skia_paint.h (working copy)
@@ -2,19 +2,19 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef GFX_CANVAS_PAINT_H_
-#define GFX_CANVAS_PAINT_H_
+#ifndef GFX_CANVAS_SKIA_PAINT_H_
+#define GFX_CANVAS_SKIA_PAINT_H_
#include "gfx/canvas.h"
#include "skia/ext/canvas_paint.h"
// Define a skia::CanvasPaint type that wraps our gfx::Canvas like the
// skia::PlatformCanvasPaint wraps PlatformCanvas.
namespace gfx {
-typedef skia::CanvasPaintT<Canvas> CanvasPaint;
+typedef skia::CanvasPaintT<CanvasSkia> CanvasSkiaPaint;
} // namespace gfx
-#endif // GFX_CANVAS_PAINT_H_
+#endif // GFX_CANVAS_SKIA_PAINT_H_
« no previous file with comments | « gfx/canvas_skia_mac.mm ('k') | gfx/canvas_skia_win.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,19 +2,19 @@
#include "gfx/canvas.h"
#include "skia/ext/canvas_paint.h"
-// Define a skia::CanvasPaint type that wraps our gfx::Canvas like the
+// Define a gfx::CanvasSkiaPaint type that wraps our gfx::Canvas like the
// skia::PlatformCanvasPaint wraps PlatformCanvas.
namespace gfx {
This is Rietveld 408576698